@@ -1,11 +1,8 @@
 // SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
-//
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #pragma once
 
-#include <QtQml/qqmlregistration.h>
-
 #include "qinvidiousglobal.h"
 
 namespace QInvidious
@@ -14,8 +11,6 @@ namespace QInvidious
 class Preferences
 {
     Q_GADGET
-    QML_ELEMENT
-    QML_UNCREATABLE("You cannot create Preferences")
 
     Q_PROPERTY(bool autoPlay MEMBER m_autoPlay)
     Q_PROPERTY(QString defaultHome MEMBER m_defaultHome)
@@ -32,7 +27,7 @@ public:
     void setDefaultHome(const QString &defaultHome);
 
 private:
-    bool m_autoPlay;
+    bool m_autoPlay = false;
     QString m_defaultHome;
     QJsonObject m_originalPreferences; // We need to store all the preferences, to not overwrite them back to default
 };
