@@ -6,6 +6,14 @@
 #include "config.h"
 #include "plasmatube.h"
 
+#ifdef HAS_DBUS
+#include <KLocalizedString>
+#include <QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusReply>
+#include <QGuiApplication>
+#endif
+
 VideoController::VideoController(QObject *parent)
     : QObject(parent)
     , m_videoModel(new VideoModel(this))
@@ -26,6 +34,43 @@ VideoController::VideoController(QObject *parent)
 
         openPlayer();
     });
+    connect(this, &VideoController::playbackStateChanged, this, [this] {
+        const bool paused = m_currentPlayer->paused();
+        const bool durationMatchesPosition = abs(m_currentPlayer->duration() - m_currentPlayer->position()) < 0.1;
+        const bool notAtBeginning = m_currentPlayer->position() > 1;
+
+        if (paused && durationMatchesPosition && notAtBeginning) {
+            m_videoQueue->next();
+        }
+
+        const bool shouldInhibit = currentPlayer() && !currentPlayer()->paused();
+
+#ifdef HAS_DBUS
+        if (shouldInhibit) {
+            QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                                  QStringLiteral("/ScreenSaver"),
+                                                                  QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                                  QStringLiteral("Inhibit"));
+            message << QGuiApplication::desktopFileName();
+            message << i18n("Playing video");
+
+            QDBusReply<uint> reply = QDBusConnection::sessionBus().call(message);
+            if (reply.isValid()) {
+                screenSaverDbusCookie = reply.value();
+            }
+        } else {
+            if (screenSaverDbusCookie != 0) {
+                QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                                      QStringLiteral("/ScreenSaver"),
+                                                                      QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                                      QStringLiteral("UnInhibit"));
+                message << static_cast<uint>(screenSaverDbusCookie);
+                screenSaverDbusCookie = 0;
+                QDBusConnection::sessionBus().send(message);
+            }
+        }
+#endif
+    });
 }
 
 void VideoController::play(const QString &videoId)
@@ -51,6 +96,14 @@ void VideoController::queueNext(const QString &videoId)
 void VideoController::togglePlaying()
 {
     if (m_currentPlayer != nullptr) {
+        const bool paused = m_currentPlayer->paused();
+        const bool durationMatchesPosition = abs(m_currentPlayer->duration() - m_currentPlayer->position()) < 0.1;
+        const bool notAtBeginning = m_currentPlayer->position() > 1;
+
+        if (paused && durationMatchesPosition && notAtBeginning) {
+            m_currentPlayer->setPosition(0);
+        }
+
         if (m_currentPlayer->paused()) {
             m_currentPlayer->play();
         } else {
@@ -113,6 +166,8 @@ void VideoController::setCurrentPlayer(MpvObject *mpvObject)
         Q_EMIT currentPlayerChanged();
     }
 
+    m_currentPlayer->setProperty(QStringLiteral("pause"), !PlasmaTube::instance().selectedSource()->preferences().autoPlay());
+
     Q_EMIT m_currentPlayer->command(QStringList() << QStringLiteral("stop"));
     // See https://github.com/mpv-player/mpv/issues/10029 why this is needed
     if (PlasmaTube::instance().selectedSource()->type() == VideoSource::Type::PeerTube) {
